@@ -59,10 +59,9 @@ class Page(object):
         self.widgets = widgets or []
 
         if background == Page.LCARS:
-            self.background = str(Path(Path(__file__).parent,
+            background = str(Path(Path(__file__).parent,
                                        "assets/lcars_screen.png"))
-        else:
-            self.background = background
+        self.background = background
 
         if background is not None:
             self._bg_image = pygame.image.load(background).convert()
