@@ -23,7 +23,8 @@ class Label(IWidget):
     def __init__(self, position, size,
                  font_size=None,
                  label=None,
-                 label_color1=None):
+                 label_color1=None,
+                 **kwargs):
         """ Initialize the label with a subset of the Widget parameters.
 
         Parameters
@@ -41,7 +42,7 @@ class Label(IWidget):
         label_color1 : Union[Tuple[int, int, int], Tuple[int, int, int, int]]
             Color of the Label
         """
-        font_size = size[1] if font_size is None else font_size
+        font_size = font_size or size[1]
         super(Label, self).__init__(position, size,
                                     font_size=font_size,
                                     label=label,
@@ -61,7 +62,7 @@ class Light(IWidget):
     """ Lights are circles whose color state is determined by their function.
     """
 
-    def __init__(self, position, size, function):
+    def __init__(self, position, size, function, **kwargs):
         """ Initialize the light with a subset of the Widget parameters.
 
         Parameters
@@ -80,8 +81,8 @@ class Light(IWidget):
         super(Light, self).__init__(position, size)
 
         self.function = function
-        self.radius = min(size[0], size[1]) >> 1
-        self.center = (self.x + self.w // 2), (self.y + self.h // 2)
+        self._radius = min(size[0], size[1]) >> 1
+        self._center = (self._x + self._w // 2), (self._y + self._h // 2)
 
     def render(self, surface):
         if self.function is None:
@@ -90,9 +91,9 @@ class Light(IWidget):
         else:
             color1, color2 = self.function(self)
         # Fill
-        pygame.draw.circle(surface, color2, self.center, self.radius, 0)
+        pygame.draw.circle(surface, color2, self._center, self._radius, 0)
         # Outline ring
-        pygame.draw.circle(surface, color1, self.center, self.radius, 2)
+        pygame.draw.circle(surface, color1, self._center, self._radius, 2)
 
     def can_focus(self):
         return False
@@ -125,10 +126,10 @@ class Indicator(IWidget):
         # Set up the boxing behavior and font size.
         kw_font_size = kwargs.pop('font_size', None)
         if kwargs.get('color1') is None:
-            self.box = False
-            font_size = size[1] if kw_font_size is None else kw_font_size
+            self._box = False
+            font_size = kw_font_size or size[1]
         else:
-            self.box = True
+            self._box = True
             font_size = kw_font_size or (size[1] >> 1)
         self.function = function
 
@@ -142,11 +143,11 @@ class Indicator(IWidget):
         else:
             active, label = False, None
         # Default to the internal label
-        label = self.label if label is None else label
+        label = label or self.label
 
         color, label_color = self.state_colors(active=active)
 
-        if self.box:
+        if self._box:
             pygame.draw.rect(surface, color, (self.position, self.size), 0)
 
         self.render_centered_text(surface, label, label_color)
@@ -194,8 +195,8 @@ class Graph(IWidget):
             # scale the font appropriately.
             samples = self.function(self, 1)
             ratio_h = max(2.5, len(samples))
-            self.graph_font = pygame.font.Font(FONT_NAME,
-                                               int(self.h / ratio_h + 0.5))
+            self._graph_font = pygame.font.Font(FONT_NAME,
+                                                int(self._h / ratio_h + 0.5))
 
     def render(self, surface):
         """ Render the graph.
@@ -205,8 +206,8 @@ class Graph(IWidget):
         values in the graph optinally data rendered as labels to the right
         (but inside) of the graph.
         """
-        graph_pos = (self.x, self.y)
-        graph_size = (self.w, self.h)
+        graph_pos = (self._x, self._y)
+        graph_size = (self._w, self._h)
         pygame.draw.rect(surface, self.color1, (graph_pos, graph_size), 2)
 
         # We can only draw the graph(s) if there is an update method
@@ -246,9 +247,9 @@ class Graph(IWidget):
                 """ Scale the value to fit the graph box."""
                 inset_range = range * 1.1
                 center_val = value - (range / 2.0)
-                return self.y + (self.h / 2.0
-                                 - ((center_val - min_val) / inset_range)
-                                 * self.h)
+                return self._y + (self._h / 2.0
+                                  - ((center_val - min_val) / inset_range)
+                                  * self._h)
 
             # Need two data points to start the graph
             if len(data) > 1:
@@ -264,18 +265,18 @@ class Graph(IWidget):
 
                 # Render the graph trailing value
                 if self.quiet is not True:
-                    text = self.graph_font.render(
+                    text = self._graph_font.render(
                         snapped_value_string(data[-1], 0.1),
                         1,
                         color)
                     textpos = text.get_rect()
-                    textpos.right = (self.x + self.w) - self.LABEL_INSET
+                    textpos.right = (self._x + self._w) - self.LABEL_INSET
                     # The text tracks the graph line, unless it's outside the
                     # extents, then we clamp it to inside.
                     if (prev_y + textpos.h + self.LABEL_INSET) > (
-                            self.y + self.h):
+                            self._y + self._h):
                         textpos.bottom = prev_y - self.LABEL_INSET
-                    elif (prev_y - textpos.h - self.LABEL_INSET) < self.y:
+                    elif (prev_y - textpos.h - self.LABEL_INSET) < self._y:
                         textpos.top = prev_y + self.LABEL_INSET
                     else:
                         textpos.centery = prev_y
