@@ -5,16 +5,15 @@
     Manual Test - set up some pages for viewing and interaction.
 """
 import logging
-from pathlib import Path
+import pprint
 
 import pygame
 
 from gui import GUI
+from page import Page
 from pi_touch_gui._utilities import backlog_error
 from raspberrypi_ts import Touchscreen
-from test_pages.entry_page import entry_page
-from test_pages.poweroff_page import poweroff_page
-from test_pages.sampler_page import sampler_page
+from test_pages.pages import get_pages
 
 logging.basicConfig(
     level=logging.INFO,
@@ -24,44 +23,37 @@ logging.basicConfig(
 )
 LOG = logging.getLogger(__name__)
 
+
+def go_to_page(name):
+    for page in pages:
+        if page.name == name:
+            return page
+    return None
+
+
+# Callback ping
+def ping(gui, page):
+    print(f"PING {page.name!r}")
+
+
 if __name__ == "__main__":
     pygame.init()
 
     touchscreen = Touchscreen()
     interface = GUI(touchscreen)
 
-    _entry_page = entry_page()
-    _sampler_page = sampler_page()
-    _poweroff_page = poweroff_page()
-
-
-    # Page transition functions
-    def go_to_page_1(button, pushed):
-        return _entry_page
-
-
-    def go_to_page_2(page, pushed):
-        return _sampler_page
-
-
-    def go_to_page_3(button, pushed):
-        return _poweroff_page
-
-
-    _entry_page.config(go_to_page_2)
-    _background = str(Path(Path(__file__).parent, "assets/lcars_screen.png"))
-    _sampler_page.config(_background, go_to_page_3, go_to_page_1)
-    _poweroff_page.config(go_to_page_2)
-
-
-    # Callback ping
-    def ping(gui, page):
-        print(f"PING {page.name!r}")
+    pages = get_pages()
 
+    for page in pages:
+        serialized_page = page.serialize()
+        rehydrated_page = Page.deserialize(serialized_page)
+        reserialized_page = rehydrated_page.serialize()
+        # Can't actually compare pages - some calculated values don't seem
+        # to match, and definitely the widget IDs get rebuilt on it
 
     try:
         # Add any hardware or other initialization here
-        interface.run(_entry_page, callback=ping, cb_rate=1000)
+        interface.run(pages[0], callback=ping, cb_rate=1000)
     except Exception as e:
         backlog_error(e, f"Unmanaged exception {type(e)}: {e}")
     finally:
